# -*-coding=utf-8 -*-
__author__  = "9304.com"
__date__    = "2020-04-20"

from setuptools import setup, find_packages
import sys
import os

# 如果是Windows，显示“nt”，如果是Linux，则“posix”
from luckdog.__version__ import __VERSION__

setup(
    name="luckdog",
    version = __VERSION__,
    author="goblinintree",
    author_email="goblinintree@126.com",
    description="a light-minded faceman,like postman.",
    long_description=open("README.md",encoding="UTF-8").read(),
    long_description_content_type="text/markdown",
    platforms=["all"],
    license="MIT",
    keywords = ['postman', 'faceman', 'test'],
    url="https://pypi.org/project/luckdog/#description",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Environment :: Web Environment",
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft',
        'Programming Language :: Python :: 3.7',
    ],
    zip_safe=True,
    install_requires=[
        "requests",
    ],
)